
# Slot: object




URI: [biolink:exon_to_transcript_relationship_object](https://w3id.org/biolink/vocab/exon_to_transcript_relationship_object)


## Domain and Range

[ExonToTranscriptRelationship](ExonToTranscriptRelationship.md) &#8594;  <sub>1..1</sub> [Transcript](Transcript.md)

## Parents

 *  is_a: [sequence feature relationship➞object](sequence_feature_relationship_object.md)

## Children


## Used by

 * [ExonToTranscriptRelationship](ExonToTranscriptRelationship.md)
